<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service\Common\PhoneSms;

use Admin\Data\Common;
use Laminas\Json\Json;
use TencentCloud\Common\Credential;
use TencentCloud\Common\Exception\TencentCloudSDKException;
use TencentCloud\Common\Profile\ClientProfile;
use TencentCloud\Common\Profile\HttpProfile;
use TencentCloud\Sms\V20190711\Models\SendSmsRequest;
use TencentCloud\Sms\V20190711\SmsClient;

class TencentSms
{
    private $sendSms;
    private $sendSmsQuery;

    public function setSmsConfig($smsConfig)
    {
        $cred = new Credential($smsConfig['sms_id'], $smsConfig['sms_secret']);
        $httpProfile = new HttpProfile();
        $httpProfile->setEndpoint("sms.tencentcloudapi.com");

        $clientProfile = new ClientProfile();
        $clientProfile->setSignMethod('TC3-HMAC-SHA256');
        $clientProfile->setHttpProfile($httpProfile);
        $this->sendSmsQuery = new SmsClient($cred, "ap-beijing", $clientProfile);

        $this->sendSms = new SendSmsRequest();
        $this->sendSms->SmsSdkAppid= $smsConfig['sms_sdk_id'];
        $this->sendSms->Sign       = $smsConfig['sms_sign_name'];
    }

    /**
     * 发送短信
     * @param array $data
     * @return bool
     */
    public function sendPhoneSms(array $data)
    {
        try {
            $this->sendSms->fromJsonString(Json::encode(['PhoneNumberSet' => $this->getPhoneNumbers($data['phone']), 'TemplateID' => $data['templateCode'], 'TemplateParamSet' => $this->createSmsContent($data['contentArray'])]));
            return $this->sendSmsQuery->SendSms($this->sendSms);
        } catch (TencentCloudSDKException $e) {
            echo $e;
        }
        return false;
    }

    /**
     * 发送订单短信
     * @param array $data
     * @return bool
     */
    public function sendOrderPhoneSms(array $data)
    {
        try {
            $this->sendSms->fromJsonString(Json::encode(['PhoneNumberSet' => $this->getPhoneNumbers($data['phone']), 'TemplateID' => $data['templateCode'], 'TemplateParamSet' => $this->createOrderSmsContent($data['contentArray'])]));
            return $this->sendSmsQuery->SendSms($this->sendSms);
        } catch (TencentCloudSDKException $e) {
            echo $e;
        }
        return false;
    }

    /**
     * 获取发送电话号码
     * @param $phoneData
     * @return array
     */
    private function getPhoneNumbers($phoneData)
    {
        $phoneArea      = Common::configValue('list', 'phoneArea');
        $phoneNumbers   = [];
        foreach ($phoneData as $value) {
            $phoneNumbers[] = '+'.$phoneArea[$value['areaCode']]['areaPhoneCode'].$value['number'];
        }

        return $phoneNumbers;
    }

    /**
     * 对短信内容进行解析
     * @param $data
     * @return array|string[]
     */
    private function createSmsContent($data)
    {
        if (empty($data)) return [];

        $contentArray = [
            $data['phoneCaptcha'] ?? '',    //验证码

            $data['userName'] ?? '',        //客户名称
            $data['changeTime'] ?? '',      //变动时间
            $data['changeAmountType'] ?? '',//变动类型
            $data['changeUserAmount'] ?? '',//变动金额
            $data['userAmount'] ?? '',      //变动后总额
        ];

        return array_values(array_filter($contentArray));
    }

    /**
     * 对订单提醒的短信内容进行解析
     * @param $data
     * @return array|string[]
     */
    private function createOrderSmsContent($data)
    {
        if (empty($data)) return [];

        $contentArray = [
            $data['buyName'] ?? '',         //买家名称
            $data['orderSn'] ?? '',         //订单编号
            $data['orderTotal'] ?? '',      //订单金额
            $data['deliveryName'] ?? '',    //快递名称
            $data['expressNumber'] ?? '',   //快递单号
        ];

        return array_values(array_filter($contentArray));

    }
}