<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Validator;

use Laminas\I18n\Translator\Translator;
use Laminas\Validator\AbstractValidator;

class CmsClassValidator extends AbstractValidator
{
    const NOT_SCALAR    = 'notScalar';
    const NOT_SELF      = 'notSelf';

    protected $options = [
        'entityManager',
        'cmsClass'
    ];

    protected $messageTemplates = [];

    public function __construct($options = [])
    {
        if(is_array($options)) {
            if(isset($options['entityManager']))    $this->options['entityManager'] = $options['entityManager'];
            if(isset($options['cmsClass']))         $this->options['cmsClass']      = $options['cmsClass'];
        }

        $trans = new Translator();
        $this->messageTemplates = [
            self::NOT_SCALAR    => $trans->translate("这不是一个标准输入值"),
            self::NOT_SELF      => $trans->translate("不能为分类本身")
        ];

        parent::__construct($options);
    }

    public function isValid($value)
    {
        if(!is_scalar($value)) {
            $this->error(self::NOT_SCALAR);
            return false;
        }

        if($this->options['cmsClass'] == null || $value == 0) return true;

        if($this->options['cmsClass']->getCmsClassId() == $value) {
            $this->error(self::NOT_SELF);
            return false;
        }

        return true;
    }
}