<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Form;

use Laminas\Form\Form;

class GoodsTagForm extends Form
{
    public function __construct($name = 'goods-tag-form', $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        $this->add([
            'type'  => 'select',
            'name'  => 'tagGroupId',
            'attributes'    => [
                'id'            => 'tagGroupId',
                'class'         => 'form-control'
            ]
        ]);

        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'tagName'.$language,
                'attributes'    => [
                    'id'            => 'tagName'.$language,
                    'class'         => 'form-control'
                ]
            ]);
        }

        $this->add([
            'type'  => 'number',
            'name'  => 'tagSort',
            'attributes'    => [
                'id'            => 'tagSort',
                'class'         => 'form-control',
                'value'         => 255
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        $inputFilter->add([
            'name'      => 'tagGroupId',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'tagName'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'tagSort',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);
    }
}