<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\GoodsBrand;
use Goods\Entity\GoodsBrandContent;
use Goods\Entity\GoodsBrandInClass;

class GoodsBrandInClassRepository extends EntityRepository
{
    /**
     * 获取分类对应的品牌 前台
     * @param $classId
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findBrandInClass($classId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('i', 'c.brandName', 'b.brandLogo')
            ->from(GoodsBrandInClass::class, 'i')
            ->innerJoin(GoodsBrand::class, 'b', Join::WITH, 'i.brandId = b.brandId')
            ->leftJoin(GoodsBrandContent::class, 'c', Join::WITH, 'i.brandId = c.brandId')
            ->where('i.classId = :classId')->setParameter('classId', $classId)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->orderBy('b.brandSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}