<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsTagGroupContent;

class GoodsTagGroupContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加和编辑标签组内容
     * @param array $data
     * @param $tagGroupId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditTagGroupContent(array $data, $tagGroupId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $groupContent = $this->entityManager->getRepository(GoodsTagGroupContent::class)->findOneBy(['tagGroupId' => $tagGroupId, 'languageCode' => $language]);
            if ($groupContent) {
                $groupContent->setTagGroupName($data['tagGroupName'.$language]);
            } else {
                $groupContent = new GoodsTagGroupContent();
                $groupContent->setTagGroupId($tagGroupId);
                $groupContent->setLanguageCode($language);
                $groupContent->setTagGroupName($data['tagGroupName'.$language]);

                $this->entityManager->persist($groupContent);
            }

            $this->entityManager->flush();
        }
    }

    /**
     * 删除标签组内容
     * @param $tagGroupId
     * @return void
     */
    public function deleteTagGroupContent($tagGroupId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsTagGroupContent::class, 'c')->where($qb->expr()->eq('c.tagGroupId', $tagGroupId));
        $qb->getQuery()->execute();
    }
}